@@ -17,6 +17,8 @@ try:
 except ImportError:
     from base64 import decodestring as b64decode
 
+from django.utils.encoding import smart_str
+
 def send_templated_mail(template_name, email_context, recipients, sender=None, bcc=None, fail_silently=False, files=None):
     """
     send_templated_mail() is a warpper around Django's e-mail routines that
@@ -52,9 +54,7 @@ def send_templated_mail(template_name, email_context, recipients, sender=None, b
     import os
 
     context = Context(email_context)
-    locale = getattr(context['queue'], 'locale', '')
-    if not locale:
-        locale = 'en'
+    locale = context['queue'].get('locale', 'en')
 
     t = None
     try:
@@ -79,15 +79,15 @@ def send_templated_mail(template_name, email_context, recipients, sender=None, b
 
     email_html_base_file = os.path.join('helpdesk', locale, 'email_html_base.html')
 
-    
+
     ''' keep new lines in html emails '''
     from django.utils.safestring import mark_safe
-    
+
     if context.has_key('comment'):
         html_txt = context['comment']
         html_txt = html_txt.replace('\r\n', '<br>')
         context['comment'] = mark_safe(html_txt)
-    
+
     html_part = loader.get_template_from_string(
         "{%% extends '%s' %%}{%% block title %%}%s{%% endblock %%}{%% block content %%}%s{%% endblock %%}" % (email_html_base_file, t.heading, t.html)
         ).render(context)
@@ -119,104 +119,6 @@ def send_templated_mail(template_name, email_context, recipients, sender=None, b
     return msg.send(fail_silently)
 
 
-def normalise_data(data, to=100):
-    """
-    Used for normalising data prior to graphing with Google charting API. EG:
-
-        [1, 4, 10] becomes [10, 40, 100]
-        [36, 54, 240] becomes [15, 23, 100]
-    """
-    max_value = max(data)
-    if max_value > to:
-        new_data = []
-        for d in data:
-            new_data.append(int(d/float(max_value)*to))
-        data = new_data
-    return data
-
-
-def line_chart(data):
-    """
-    'data' is a list of lists making a table.
-    Row 1, columns 2-n are data headings (the time periods)
-    Rows 2-n are data, with column 1 being the line labels
-    """
-
-    column_headings = data[0][1:]
-    max = 0
-    for row in data[1:]:
-        for field in row[1:]:
-            if field > max:
-                max = field
-
-
-    # Set width to '65px * number of months + 100 for headings.'.
-    chart_url = 'http://chart.apis.google.com/chart?cht=lc&chs=%sx150&chd=t:' % (min(len(column_headings)*65+100, 1000))
-    first_row = True
-    row_headings = []
-    for row in data[1:]:
-        # Add data to URL, normalised to the maximum for all lines on this chart
-        norm = normalise_data(row[1:], max)
-        if not first_row:
-            chart_url += '|'
-        chart_url += ','.join([str(num) for num in norm])
-        row_headings.append(row[0])
-        first_row = False
-
-    chart_url += '&chds='
-    rows = len(data)-1
-    first = True
-    for row in range(rows):
-        # Set maximum data ranges to '0:x' where 'x' is the maximum number in use.
-        if not first:
-            chart_url += ','
-        chart_url += '0,%s' % max
-        first = False
-    chart_url += '&chdl=%s' % '|'.join(row_headings) # Display legend/labels
-    chart_url += '&chco=%s' % ','.join(chart_colours) # Default colour set
-    chart_url += '&chxt=x,y' # Turn on axis labels
-    chart_url += '&chxl=0:|%s|1:|0|%s' % ('|'.join(column_headings), max) # Axis Label Text
-
-    return chart_url
-
-
-def bar_chart(data):
-    """
-    'data' is a list of lists making a table.
-    Row 1, columns 2-n are data headings
-    Rows 2-n are data, with column 1 being the line labels
-    """
-
-    column_headings = data[0][1:]
-    max = 0
-    for row in data[1:]:
-        for field in row[1:]:
-            if field > max:
-                max = field
-
-
-    # Set width to '220px * number of months'.
-    chart_url = 'http://chart.apis.google.com/chart?cht=bvg&chs=%sx150&chd=t:' % (min(len(column_headings) * 220, 1000))
-    first_row = True
-    row_headings = []
-    for row in data[1:]:
-        # Add data to URL, normalised to the maximum for all lines on this chart
-        norm = normalise_data(row[1:], max)
-        if not first_row:
-            chart_url += '|'
-        chart_url += ','.join([str(num) for num in norm])
-        row_headings.append(row[0])
-        first_row = False
-
-    chart_url += '&chds=0,%s' % max
-    chart_url += '&chdl=%s' % '|'.join(row_headings) # Display legend/labels
-    chart_url += '&chco=%s' % ','.join(chart_colours) # Default colour set
-    chart_url += '&chxt=x,y' # Turn on axis labels
-    chart_url += '&chxl=0:|%s|1:|0|%s' % ('|'.join(column_headings), max) # Axis Label Text
-
-    return chart_url
-
-
 def query_to_dict(results, descriptions):
     """
     Replacement method for cursor.dictfetchall() as that method no longer
@@ -242,13 +144,13 @@ def apply_query(queryset, params):
     """
     Apply a dict-based set of filters & paramaters to a queryset.
 
-    queryset is a Django queryset, eg MyModel.objects.all() or 
+    queryset is a Django queryset, eg MyModel.objects.all() or
              MyModel.objects.filter(user=request.user)
 
     params is a dictionary that contains the following:
         filtering: A dict of Django ORM filters, eg:
             {'user__id__in': [1, 3, 103], 'title__contains': 'foo'}
-        other_filter: Another filter of some type, most likely a 
+        other_filter: Another filter of some type, most likely a
             set of Q() objects.
         sorting: The name of the column to sort by
     """
@@ -272,7 +174,7 @@ def safe_template_context(ticket):
     """
     Return a dictionary that can be used as a template context to render
     comments and other details with ticket or queue paramaters. Note that
-    we don't just provide the Ticket & Queue objects to the template as 
+    we don't just provide the Ticket & Queue objects to the template as
     they could reveal confidential information. Just imagine these two options:
         * {{ ticket.queue.email_box_password }}
         * {{ ticket.assigned_to.password }}
@@ -296,7 +198,7 @@ def safe_template_context(ticket):
         else:
             context['queue'][field] = attr
 
-    for field in (  'title', 'created', 'modified', 'submitter_email', 
+    for field in (  'title', 'created', 'modified', 'submitter_email',
                     'status', 'get_status_display', 'on_hold', 'description',
                     'resolution', 'priority', 'get_priority_display',
                     'last_escalation', 'ticket', 'ticket_for_url',
@@ -317,7 +219,7 @@ def safe_template_context(ticket):
 def text_is_spam(text, request):
     # Based on a blog post by 'sciyoshi':
     # http://sciyoshi.com/blog/2008/aug/27/using-akismet-djangos-new-comments-framework/
-    # This will return 'True' is the given text is deemed to be spam, or 
+    # This will return 'True' is the given text is deemed to be spam, or
     # False if it is not spam. If it cannot be checked for some reason, we
     # assume it isn't spam.
     from django.contrib.sites.models import Site
@@ -349,6 +251,6 @@ def text_is_spam(text, request):
             'comment_author': '',
         }
 
-        return ak.comment_check(text, data=ak_data)
+        return ak.comment_check(smart_str(text), data=ak_data)
 
     return False
